library(readr)
library(data.table)
library(haven)
library(bit64)
library(zoo)
library(ggplot2)
library(xtable)
library(foreign)

options(scipen = 999)



setwd("I:/Workdata/706362/js/Global_Income/REPLICATION_PACK/data")

rm(list=ls())
cat("\014")





demog_dt <- as.data.table(read_csv("bef.csv" ))

educ_dt <- as.data.table(read_csv("uddaupd.csv" ))

wage_dt <- as.data.table(read_csv("lon.csv",col_types = 'nnnnnnnnn' ))



##
setwd("I:/Workdata/706362/js/Global_Income/REPLICATION_PACK/dta")


##

demog_dt[,QWE:=as.numeric(QWE)]



demog_dt[,year:=befupdSourceYear-1]
demog_dt[,gender:=ifelse(KOEN==1,'male','female')]
demog_dt[,born := as.Date(FOED_DAG,"%d/%m/%Y")]
demog_dt[,age:=year-year(born)]
demog<-demog_dt[age>=20 & age<=55]




#select all individuals
demog_indi_dt<-unique(demog[,.(QWE,gender,born)])
setkey(demog_indi_dt,QWE)
demog_indi_dt<-unique(demog_indi_dt,by='QWE')

#create balanced set
balanced_dt<-demog_indi_dt[rep(1:.N,39),.(QWE,gender,born)]
balanced_dt[,year:=seq_len(.N), by=.(QWE)]
balanced_dt[,year:=year+1979]
balanced_dt[,age:=year-year(born)]
balanced_dt<-balanced_dt[age>=20 & age<=55 & year <= 2018]


#Create education levels
edu_format<- read_sas('uddan_2014_audd.sas7bdat')
ef_dt <- as.data.table(edu_format)
ef_dt[h1==10,education:=as.factor('1')]
ef_dt[h1==35,education:=as.factor('2')]
ef_dt[h1==20 | h1==25,education:=as.factor('3')]
ef_dt[h1==40 | h1==50 | h1==60 ,education:=as.factor('4')]
ef_dt[h1==65 | h1==70 ,education:=as.factor('5')]
ef_dt <- na.omit(ef_dt, cols=c('audd'))
ef_dt[, HFAUDD:= as.integer(audd)]
cols = c('education', 'HFAUDD')
ef_dt <- ef_dt[,cols, with=FALSE]



setnames(educ_dt,'uddaupdSourceYear','year')
educ_dt <- na.omit(educ_dt, cols=c('QWE','HFAUDD'))
educ_dt <- educ_dt[, c('QWE', 'HFAUDD','year'), with=FALSE]
educ_dt <- ef_dt[educ_dt, on=c('HFAUDD')]
educ_dt[,HFAUDD:=NULL]

educ_indi_dt<-unique(educ_dt[,.(QWE,education)])
educ_indi_dt[,.N,education]
educ_indi_dt<-educ_indi_dt[order(QWE,-education)]
educ_indi_dt<-unique(educ_indi_dt[!is.na(education)],by='QWE')
educ_indi_dt[,.N,education]


wage_dt <- na.omit(wage_dt, cols='QWE')
setnames(wage_dt,'indupd01SourceYear','year')
str(wage_dt)
#############
# wage_dt[,LOENMV:=as.numeric(LOENMV)]
# wage_dt[,DISPON_NY:=as.numeric(DISPON_NY)]
# wage_dt[,PERINDKIALT:=as.numeric(PERINDKIALT)]

#Choose _13 where available, otherwise regress to old measure
wage_dt[,wage:=LOENMV_13]
wage_dt[is.na(wage),wage:=LOENMV]
wage_dt[,income:=PERINDKIALT_13]
wage_dt[is.na(income),income:=PERINDKIALT]

#KORRIGER FOR "LEJEV_EGEN_BOLIG"
wage_dt[is.na(LEJEV_EGEN_BOLIG),LEJEV_EGEN_BOLIG:=0]

wage_dt[,disp:=DISPON_13]
wage_dt[is.na(disp),disp:=DISPON_NY]
wage_dt[,disp:=disp-LEJEV_EGEN_BOLIG]




wage2_dt<-wage_dt[,.(QWE,year,wage,income,disp)]
wage2_dt<-unique(wage2_dt)

###
# Merge data sets
educ_indi_dt[,QWE:=as.numeric(QWE)]
data_dt <- merge(balanced_dt,educ_indi_dt,by='QWE',all.x=T)
data_dt <- merge(data_dt,wage2_dt,by=c('QWE','year'),all.x=T)



################


# Individual sets

data_out<-data_dt[,.(QWE,year,gender,born,education,wage,disp,income)]
data_out[,male:=0]
data_out[gender=='male',male:=1]
data_out[,b_year:=year(born)]
setnames(data_out,'QWE','idnr')
setnames(data_out,'education','educ')
setnames(data_out,'wage','wage_inc')
setnames(data_out,'disp','disp_inc')
setnames(data_out,'income','income_inc')
data_out[,gender:=NULL]
data_out[,born:=NULL]
data_out[,yod:=NA]







############

# Restrict to 28.500 a year

#load CPI, index 2018
cpi_dt<-as.data.table(t(read.table('CPI.txt')))
colnames(cpi_dt)<-c('year','cpi')
cpi_dt[,year:=as.numeric(year)]
cpi_dt[,cpi:=as.numeric(gsub(',','.',cpi))]
cpi_dt[,cpi:=cpi*100/(cpi_dt[year==2018]$cpi)]
cpi_dt[,limit:=28500*cpi/100]




data_out_2w<- merge(data_out,cpi_dt,by='year')

data_out_2w[,wage_inc_restr:= wage_inc]
data_out_2w[disp_inc<limit ,wage_inc_restr:= 0]

data_out_2w[,income_inc_restr:= income_inc]
data_out_2w[disp_inc<limit ,income_inc_restr:= 0]

data_out_2w[,disp_inc_restr:= disp_inc]
data_out_2w[wage_inc<limit | is.na(wage_inc),disp_inc_restr:= 0]


###########################

## Final wide format, 
# wage earnings
data_out_w<-dcast(data_out_2w,idnr+educ+male+b_year+yod~year,value.var='wage_inc_restr',fun.aggregate = mean)
a<-colnames(data_out_w)
b<-c(a[1:5],paste0('wage_inc_restr',c(1980:2018)))
colnames(data_out_w)<-b
write.dta(data_out_w,'../dta/data_wide_wage_restr.dta')

# disposable income
data_out_w<-dcast(data_out_2w,idnr+educ+male+b_year+yod~year,value.var='disp_inc_restr',fun.aggregate = mean)
a<-colnames(data_out_w)
b<-c(a[1:5],paste0('disp_inc_restr',c(1980:2018)))
colnames(data_out_w)<-b
write.dta(data_out_w,'data_wide_disp_restr.dta')

# all income
data_out_w<-dcast(data_out_2w,idnr+educ+male+b_year+yod~year,value.var='income_inc_restr',fun.aggregate = mean)
a<-colnames(data_out_w)
b<-c(a[1:5],paste0('income_inc_restr',c(1980:2018)))
colnames(data_out_w)<-b
write.dta(data_out_w,'data_wide_income_restr.dta')





################
# Households

fams <- demog_dt[,.(RTY,QWE,year)]
fams[,QWE:=as.numeric(QWE)]
partners<- data_dt[,.(QWE,year,wage,disp)]
colnames(partners)<-c("p_QWE","year","p_wage","p_disp")
str(fams)
data_hh<-merge(data_dt,fams,by=c('QWE','year'),all.x=T)
data_hh[,p_QWE:=as.numeric(RTY)]

data_hh<-merge(data_hh,partners,by=c('p_QWE','year'),all.x=T)
data_hh[,hh_size:=1]
data_hh[!is.na(p_QWE),hh_size:=2]

data_hh[,hh_disp:=disp]
data_hh[hh_size==2,hh_disp:=(disp+p_disp)/2]
data_hh[,hh_wage:=wage]
data_hh[hh_size==2,hh_wage:=(wage+p_wage)/2]




data_out_hh<-data_hh[,.(QWE,year,gender,born,education,hh_wage,hh_disp,hh_size)]
data_out_hh[,male:=0]
data_out_hh[gender=='male',male:=1]
data_out_hh[,b_year:=year(born)]
setnames(data_out_hh,'QWE','idnr')
setnames(data_out_hh,'education','educ')
setnames(data_out_hh,'hh_wage','wage_inc')
setnames(data_out_hh,'hh_disp','disp_inc')
data_out_hh[,gender:=NULL]
data_out_hh[,born:=NULL]
data_out_hh[,yod:=NA]



# retrict by limit
data_out_hh<- merge(data_out_hh,cpi_dt,by='year')
data_out_hh[wage_inc<limit | is.na(wage_inc) | disp_inc<limit | is.na(disp_inc),`:=` (disp_inc=0,wage_inc=0)]

###



#convert to wide
data_out_hh_w<-dcast(data_out_hh,idnr+educ+male+b_year+yod~year,value.var='wage_inc',fun.aggregate = mean)
a<-colnames(data_out_hh_w)
b<-c(a[1:5],paste0('wage_inc',c(1980:2018)))
colnames(data_out_hh_w)<-b
write.dta(data_out_hh_w,'data_wide_hh_wage.dta')



data_out_hh_w<-dcast(data_out_hh,idnr+educ+male+b_year+yod~year,value.var='disp_inc',fun.aggregate = mean)
a<-colnames(data_out_hh_w)
b<-c(a[1:5],paste0('disp_inc',c(1980:2018)))
colnames(data_out_hh_w)<-b
write.dta(data_out_hh_w,'data_wide_hh_disp.dta')
