library(haven)
library(readr)
library(foreign)
library(data.table)
library(ggplot2)
library(gridExtra)
library(stargazer)
library(sandwich)
library(lmtest)
library(xtable)
library(latex2exp)




options(scipen = 999)

rm(list=ls())
cat("\014")

setwd("I:/Workdata/706362/js/Global_Income/REPLICATION_PACK/")
GDP<-as.data.table(t(read.table('data/GDP.txt',sep=';')))
colnames(GDP)<-c('year','GDP','GDP_growth')

GDP[,GDP_lag:=shift(GDP,1)]
GDP[,log_GDP_growth:=log(GDP)-log(GDP_lag)]
GDP[,log_GDP_growth2:=shift(log_GDP_growth,1,type='lead')]




file_in = paste0('out/21 Jun 2022 Volatility/L_researn1F_male_sumstat.csv')

moments<-as.data.table(read.table(file_in,sep=',',header = T))

moments[,p9010:= (p90researn1F  - p10researn1F  )]
moments[,p9050:= (p90researn1F  - p50researn1F  )]
moments[,p5010:= (p50researn1F  - p10researn1F  )]
moments[,ksk:= (p9050-p5010 )/(p9010)]
moments[,cku:= (p97_5researn1F  - p2_5researn1F )/(p75researn1F  -  p25researn1F ) - 2.91]

moments<-merge(moments,GDP,'year',all.x=T)


####
reg_mom <- function(var,mal){
  fit<- lm(get(var) ~ log_GDP_growth2+year, data=moments[male==mal])
  return(fit)
}
###
moms<-c('p9010','ksk','cku')#,'p9050','p5010')

out_<-matrix(' ',4,length(moms)+1)
out_[1,1]<-'Female'
out_[3,1]<-'Male'

for(m_ in 0:1){
  it=0
  for(v_ in moms){
    it=it+1
    fit<- reg_mom(v_,m_)
    ct<-coeftest(fit,vcov. = NeweyWest(fit,3))
    out_[(1+m_*2),(1+it)]<-round(ct[2,1],3)
    out_[(2+m_*2),(1+it)]<-paste0('(',round(ct[2,2],3),')')
  }
}
out_

out_ <- as.data.table(out_)
colnames(out_)<-c('Gender',moms)

file_out = '4_tables/Table_2.tex'
print(xtable(out_,align="ll|ccc",caption=paste0('Regression analysis on log GDP growth vs. moments.
                                                  Newey-West standard errors in parenthesis, maximum lag length: 3.')),
      caption.placement = 'top',include.rownames = F,file=file_out,size='small')


